# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['OriginArgs', 'Origin']

@pulumi.input_type
class OriginArgs:
    def __init__(__self__, *,
                 origin: pulumi.Input[_builtins.str],
                 scopes: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Origin resource.
        :param pulumi.Input[_builtins.str] origin: Unique origin URL for this trusted origin
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Scopes of the Trusted Origin - can either be `CORS` and/or `REDIRECT`
        :param pulumi.Input[_builtins.bool] active: Whether the Trusted Origin is active or not - can only be issued post-creation. By default, it is `true`.
        :param pulumi.Input[_builtins.str] name: Unique name for this trusted origin
        """
        pulumi.set(__self__, "origin", origin)
        pulumi.set(__self__, "scopes", scopes)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def origin(self) -> pulumi.Input[_builtins.str]:
        """
        Unique origin URL for this trusted origin
        """
        return pulumi.get(self, "origin")

    @origin.setter
    def origin(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "origin", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        Scopes of the Trusted Origin - can either be `CORS` and/or `REDIRECT`
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "scopes", value)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the Trusted Origin is active or not - can only be issued post-creation. By default, it is `true`.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique name for this trusted origin
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _OriginState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 origin: Optional[pulumi.Input[_builtins.str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Origin resources.
        :param pulumi.Input[_builtins.bool] active: Whether the Trusted Origin is active or not - can only be issued post-creation. By default, it is `true`.
        :param pulumi.Input[_builtins.str] name: Unique name for this trusted origin
        :param pulumi.Input[_builtins.str] origin: Unique origin URL for this trusted origin
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Scopes of the Trusted Origin - can either be `CORS` and/or `REDIRECT`
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if origin is not None:
            pulumi.set(__self__, "origin", origin)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the Trusted Origin is active or not - can only be issued post-creation. By default, it is `true`.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique name for this trusted origin
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def origin(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique origin URL for this trusted origin
        """
        return pulumi.get(self, "origin")

    @origin.setter
    def origin(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "origin", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Scopes of the Trusted Origin - can either be `CORS` and/or `REDIRECT`
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "scopes", value)


@pulumi.type_token("okta:trustedorigin/origin:Origin")
class Origin(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 origin: Optional[pulumi.Input[_builtins.str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Creates a Trusted Origin. This resource allows you to create and configure a Trusted Origin.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.trustedorigin.Origin("example",
            name="example",
            origin="https://example.com",
            scopes=["CORS"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:trustedorigin/origin:Origin example <trusted_origin_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] active: Whether the Trusted Origin is active or not - can only be issued post-creation. By default, it is `true`.
        :param pulumi.Input[_builtins.str] name: Unique name for this trusted origin
        :param pulumi.Input[_builtins.str] origin: Unique origin URL for this trusted origin
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Scopes of the Trusted Origin - can either be `CORS` and/or `REDIRECT`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OriginArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a Trusted Origin. This resource allows you to create and configure a Trusted Origin.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.trustedorigin.Origin("example",
            name="example",
            origin="https://example.com",
            scopes=["CORS"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:trustedorigin/origin:Origin example <trusted_origin_id>
        ```

        :param str resource_name: The name of the resource.
        :param OriginArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OriginArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 origin: Optional[pulumi.Input[_builtins.str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OriginArgs.__new__(OriginArgs)

            __props__.__dict__["active"] = active
            __props__.__dict__["name"] = name
            if origin is None and not opts.urn:
                raise TypeError("Missing required property 'origin'")
            __props__.__dict__["origin"] = origin
            if scopes is None and not opts.urn:
                raise TypeError("Missing required property 'scopes'")
            __props__.__dict__["scopes"] = scopes
        super(Origin, __self__).__init__(
            'okta:trustedorigin/origin:Origin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            origin: Optional[pulumi.Input[_builtins.str]] = None,
            scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Origin':
        """
        Get an existing Origin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] active: Whether the Trusted Origin is active or not - can only be issued post-creation. By default, it is `true`.
        :param pulumi.Input[_builtins.str] name: Unique name for this trusted origin
        :param pulumi.Input[_builtins.str] origin: Unique origin URL for this trusted origin
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: Scopes of the Trusted Origin - can either be `CORS` and/or `REDIRECT`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OriginState.__new__(_OriginState)

        __props__.__dict__["active"] = active
        __props__.__dict__["name"] = name
        __props__.__dict__["origin"] = origin
        __props__.__dict__["scopes"] = scopes
        return Origin(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def active(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the Trusted Origin is active or not - can only be issued post-creation. By default, it is `true`.
        """
        return pulumi.get(self, "active")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Unique name for this trusted origin
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def origin(self) -> pulumi.Output[_builtins.str]:
        """
        Unique origin URL for this trusted origin
        """
        return pulumi.get(self, "origin")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Scopes of the Trusted Origin - can either be `CORS` and/or `REDIRECT`
        """
        return pulumi.get(self, "scopes")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SecurityEventsProviderArgs', 'SecurityEventsProvider']

@pulumi.input_type
class SecurityEventsProviderArgs:
    def __init__(__self__, *,
                 is_enabled: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']] = None):
        """
        The set of arguments for constructing a SecurityEventsProvider resource.
        :param pulumi.Input[_builtins.str] is_enabled: Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        :param pulumi.Input[_builtins.str] type: The application type of the Security Events Provider.
        :param pulumi.Input[_builtins.str] name: The name of the Security Events Provider instance.
        :param pulumi.Input['SecurityEventsProviderSettingsArgs'] settings: Information about the Security Events Provider for signal ingestion.
        """
        pulumi.set(__self__, "is_enabled", is_enabled)
        pulumi.set(__self__, "type", type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Input[_builtins.str]:
        """
        Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The application type of the Security Events Provider.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Security Events Provider instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']]:
        """
        Information about the Security Events Provider for signal ingestion.
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']]):
        pulumi.set(self, "settings", value)


@pulumi.input_type
class _SecurityEventsProviderState:
    def __init__(__self__, *,
                 is_enabled: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SecurityEventsProvider resources.
        :param pulumi.Input[_builtins.str] is_enabled: Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        :param pulumi.Input[_builtins.str] name: The name of the Security Events Provider instance.
        :param pulumi.Input['SecurityEventsProviderSettingsArgs'] settings: Information about the Security Events Provider for signal ingestion.
        :param pulumi.Input[_builtins.str] status: Indicates whether the Security Events Provider is active or not.
        :param pulumi.Input[_builtins.str] type: The application type of the Security Events Provider.
        """
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Security Events Provider instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']]:
        """
        Information about the Security Events Provider for signal ingestion.
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input['SecurityEventsProviderSettingsArgs']]):
        pulumi.set(self, "settings", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Indicates whether the Security Events Provider is active or not.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The application type of the Security Events Provider.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:index/securityEventsProvider:SecurityEventsProvider")
class SecurityEventsProvider(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Security Events Provider instances for signal ingestion.

        ## Example Usage

        ### Security Events Provider with Well-Known URL

        ```python
        import pulumi
        import pulumi_okta as okta

        example_wellknown = okta.SecurityEventsProvider("example_wellknown",
            name="Security Events Provider with well-known URL",
            type="okta",
            is_enabled="ACTIVE",
            settings={
                "well_known_url": "https://example.com/.well-known/ssf_configuration",
            })
        ```

        ### Security Events Provider with Issuer and JWKS

        ```python
        import pulumi
        import pulumi_okta as okta

        example_issuer = okta.SecurityEventsProvider("example_issuer",
            name="Security Events Provider with an issuer and a JWKS URL",
            type="okta",
            is_enabled="ACTIVE",
            settings={
                "issuer": "Issuer",
                "jwks_url": "https://example.okta.com/jwks/path",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/securityEventsProvider:SecurityEventsProvider example <security_events_provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] is_enabled: Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        :param pulumi.Input[_builtins.str] name: The name of the Security Events Provider instance.
        :param pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']] settings: Information about the Security Events Provider for signal ingestion.
        :param pulumi.Input[_builtins.str] type: The application type of the Security Events Provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecurityEventsProviderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Security Events Provider instances for signal ingestion.

        ## Example Usage

        ### Security Events Provider with Well-Known URL

        ```python
        import pulumi
        import pulumi_okta as okta

        example_wellknown = okta.SecurityEventsProvider("example_wellknown",
            name="Security Events Provider with well-known URL",
            type="okta",
            is_enabled="ACTIVE",
            settings={
                "well_known_url": "https://example.com/.well-known/ssf_configuration",
            })
        ```

        ### Security Events Provider with Issuer and JWKS

        ```python
        import pulumi
        import pulumi_okta as okta

        example_issuer = okta.SecurityEventsProvider("example_issuer",
            name="Security Events Provider with an issuer and a JWKS URL",
            type="okta",
            is_enabled="ACTIVE",
            settings={
                "issuer": "Issuer",
                "jwks_url": "https://example.okta.com/jwks/path",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/securityEventsProvider:SecurityEventsProvider example <security_events_provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param SecurityEventsProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityEventsProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityEventsProviderArgs.__new__(SecurityEventsProviderArgs)

            if is_enabled is None and not opts.urn:
                raise TypeError("Missing required property 'is_enabled'")
            __props__.__dict__["is_enabled"] = is_enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["settings"] = settings
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["status"] = None
        super(SecurityEventsProvider, __self__).__init__(
            'okta:index/securityEventsProvider:SecurityEventsProvider',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_enabled: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            settings: Optional[pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'SecurityEventsProvider':
        """
        Get an existing SecurityEventsProvider resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] is_enabled: Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        :param pulumi.Input[_builtins.str] name: The name of the Security Events Provider instance.
        :param pulumi.Input[Union['SecurityEventsProviderSettingsArgs', 'SecurityEventsProviderSettingsArgsDict']] settings: Information about the Security Events Provider for signal ingestion.
        :param pulumi.Input[_builtins.str] status: Indicates whether the Security Events Provider is active or not.
        :param pulumi.Input[_builtins.str] type: The application type of the Security Events Provider.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityEventsProviderState.__new__(_SecurityEventsProviderState)

        __props__.__dict__["is_enabled"] = is_enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["settings"] = settings
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return SecurityEventsProvider(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Output[_builtins.str]:
        """
        Whether or not the Security Events Provider is enabled. Valid values: `ACTIVE`, `INACTIVE`.
        """
        return pulumi.get(self, "is_enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Security Events Provider instance.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def settings(self) -> pulumi.Output[Optional['outputs.SecurityEventsProviderSettings']]:
        """
        Information about the Security Events Provider for signal ingestion.
        """
        return pulumi.get(self, "settings")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Indicates whether the Security Events Provider is active or not.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The application type of the Security Events Provider.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AutoLoginArgs', 'AutoLogin']

@pulumi.input_type
class AutoLoginArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[_builtins.str],
                 accessibility_error_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 accessibility_login_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 accessibility_self_service: Optional[pulumi.Input[_builtins.bool]] = None,
                 admin_note: Optional[pulumi.Input[_builtins.str]] = None,
                 app_links_json: Optional[pulumi.Input[_builtins.str]] = None,
                 app_settings_json: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_submit_toolbar: Optional[pulumi.Input[_builtins.bool]] = None,
                 credentials_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 enduser_note: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_ios: Optional[pulumi.Input[_builtins.bool]] = None,
                 hide_web: Optional[pulumi.Input[_builtins.bool]] = None,
                 logo: Optional[pulumi.Input[_builtins.str]] = None,
                 preconfigured_app: Optional[pulumi.Input[_builtins.str]] = None,
                 reveal_password: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_password: Optional[pulumi.Input[_builtins.str]] = None,
                 shared_username: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_on_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_on_url: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_push_status: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AutoLogin resource.
        :param pulumi.Input[_builtins.str] label: The Application's display name.
        :param pulumi.Input[_builtins.str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[_builtins.str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[_builtins.bool] accessibility_self_service: Enable self service. Default is `false`
        :param pulumi.Input[_builtins.str] admin_note: Application notes for admins.
        :param pulumi.Input[_builtins.str] app_links_json: Displays specific appLinks for the app. The value for each application link should be boolean.
        :param pulumi.Input[_builtins.str] app_settings_json: Application settings in JSON format
        :param pulumi.Input[_builtins.bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[_builtins.str] credentials_scheme: Application credentials scheme. One of: `EDIT_USERNAME_AND_PASSWORD`, `ADMIN_SETS_CREDENTIALS`, `EDIT_PASSWORD_ONLY`, `EXTERNAL_PASSWORD_SYNC`, or `SHARED_USERNAME_AND_PASSWORD`
        :param pulumi.Input[_builtins.str] enduser_note: Application notes for end users.
        :param pulumi.Input[_builtins.bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[_builtins.bool] hide_web: Do not display application icon to users
        :param pulumi.Input[_builtins.str] logo: Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        :param pulumi.Input[_builtins.str] preconfigured_app: Tells Okta to use an existing application in their application catalog, as opposed to a custom application.
        :param pulumi.Input[_builtins.bool] reveal_password: Allow user to reveal password. Default is false. It can not be set to true if credentials*scheme is "ADMIN*SETS*CREDENTIALS", "SHARED*USERNAME*AND*PASSWORD" or "EXTERNAL*PASSWORD*SYNC".
        :param pulumi.Input[_builtins.str] shared_password: Shared password, required for certain schemes.
        :param pulumi.Input[_builtins.str] shared_username: Shared username, required for certain schemes.
        :param pulumi.Input[_builtins.str] sign_on_redirect_url: Post login redirect URL
        :param pulumi.Input[_builtins.str] sign_on_url: Login URL
        :param pulumi.Input[_builtins.str] status: Status of application. By default, it is `ACTIVE`
        :param pulumi.Input[_builtins.str] user_name_template: Username template. Default: `${source.login}`
        :param pulumi.Input[_builtins.str] user_name_template_push_status: Push username on update. Valid values: `PUSH` and `DONT_PUSH`
        :param pulumi.Input[_builtins.str] user_name_template_suffix: Username template suffix
        :param pulumi.Input[_builtins.str] user_name_template_type: Username template type. Default: `BUILT_IN`
        """
        pulumi.set(__self__, "label", label)
        if accessibility_error_redirect_url is not None:
            pulumi.set(__self__, "accessibility_error_redirect_url", accessibility_error_redirect_url)
        if accessibility_login_redirect_url is not None:
            pulumi.set(__self__, "accessibility_login_redirect_url", accessibility_login_redirect_url)
        if accessibility_self_service is not None:
            pulumi.set(__self__, "accessibility_self_service", accessibility_self_service)
        if admin_note is not None:
            pulumi.set(__self__, "admin_note", admin_note)
        if app_links_json is not None:
            pulumi.set(__self__, "app_links_json", app_links_json)
        if app_settings_json is not None:
            pulumi.set(__self__, "app_settings_json", app_settings_json)
        if auto_submit_toolbar is not None:
            pulumi.set(__self__, "auto_submit_toolbar", auto_submit_toolbar)
        if credentials_scheme is not None:
            pulumi.set(__self__, "credentials_scheme", credentials_scheme)
        if enduser_note is not None:
            pulumi.set(__self__, "enduser_note", enduser_note)
        if hide_ios is not None:
            pulumi.set(__self__, "hide_ios", hide_ios)
        if hide_web is not None:
            pulumi.set(__self__, "hide_web", hide_web)
        if logo is not None:
            pulumi.set(__self__, "logo", logo)
        if preconfigured_app is not None:
            pulumi.set(__self__, "preconfigured_app", preconfigured_app)
        if reveal_password is not None:
            pulumi.set(__self__, "reveal_password", reveal_password)
        if shared_password is not None:
            pulumi.set(__self__, "shared_password", shared_password)
        if shared_username is not None:
            pulumi.set(__self__, "shared_username", shared_username)
        if sign_on_redirect_url is not None:
            pulumi.set(__self__, "sign_on_redirect_url", sign_on_redirect_url)
        if sign_on_url is not None:
            pulumi.set(__self__, "sign_on_url", sign_on_url)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if user_name_template is not None:
            pulumi.set(__self__, "user_name_template", user_name_template)
        if user_name_template_push_status is not None:
            pulumi.set(__self__, "user_name_template_push_status", user_name_template_push_status)
        if user_name_template_suffix is not None:
            pulumi.set(__self__, "user_name_template_suffix", user_name_template_suffix)
        if user_name_template_type is not None:
            pulumi.set(__self__, "user_name_template_type", user_name_template_type)

    @_builtins.property
    @pulumi.getter
    def label(self) -> pulumi.Input[_builtins.str]:
        """
        The Application's display name.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter(name="accessibilityErrorRedirectUrl")
    def accessibility_error_redirect_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom error page URL
        """
        return pulumi.get(self, "accessibility_error_redirect_url")

    @accessibility_error_redirect_url.setter
    def accessibility_error_redirect_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "accessibility_error_redirect_url", value)

    @_builtins.property
    @pulumi.getter(name="accessibilityLoginRedirectUrl")
    def accessibility_login_redirect_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom login page URL
        """
        return pulumi.get(self, "accessibility_login_redirect_url")

    @accessibility_login_redirect_url.setter
    def accessibility_login_redirect_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "accessibility_login_redirect_url", value)

    @_builtins.property
    @pulumi.getter(name="accessibilitySelfService")
    def accessibility_self_service(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable self service. Default is `false`
        """
        return pulumi.get(self, "accessibility_self_service")

    @accessibility_self_service.setter
    def accessibility_self_service(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "accessibility_self_service", value)

    @_builtins.property
    @pulumi.getter(name="adminNote")
    def admin_note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application notes for admins.
        """
        return pulumi.get(self, "admin_note")

    @admin_note.setter
    def admin_note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "admin_note", value)

    @_builtins.property
    @pulumi.getter(name="appLinksJson")
    def app_links_json(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Displays specific appLinks for the app. The value for each application link should be boolean.
        """
        return pulumi.get(self, "app_links_json")

    @app_links_json.setter
    def app_links_json(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_links_json", value)

    @_builtins.property
    @pulumi.getter(name="appSettingsJson")
    def app_settings_json(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application settings in JSON format
        """
        return pulumi.get(self, "app_settings_json")

    @app_settings_json.setter
    def app_settings_json(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_settings_json", value)

    @_builtins.property
    @pulumi.getter(name="autoSubmitToolbar")
    def auto_submit_toolbar(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Display auto submit toolbar
        """
        return pulumi.get(self, "auto_submit_toolbar")

    @auto_submit_toolbar.setter
    def auto_submit_toolbar(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_submit_toolbar", value)

    @_builtins.property
    @pulumi.getter(name="credentialsScheme")
    def credentials_scheme(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application credentials scheme. One of: `EDIT_USERNAME_AND_PASSWORD`, `ADMIN_SETS_CREDENTIALS`, `EDIT_PASSWORD_ONLY`, `EXTERNAL_PASSWORD_SYNC`, or `SHARED_USERNAME_AND_PASSWORD`
        """
        return pulumi.get(self, "credentials_scheme")

    @credentials_scheme.setter
    def credentials_scheme(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credentials_scheme", value)

    @_builtins.property
    @pulumi.getter(name="enduserNote")
    def enduser_note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application notes for end users.
        """
        return pulumi.get(self, "enduser_note")

    @enduser_note.setter
    def enduser_note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "enduser_note", value)

    @_builtins.property
    @pulumi.getter(name="hideIos")
    def hide_ios(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Do not display application icon on mobile app
        """
        return pulumi.get(self, "hide_ios")

    @hide_ios.setter
    def hide_ios(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_ios", value)

    @_builtins.property
    @pulumi.getter(name="hideWeb")
    def hide_web(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Do not display application icon to users
        """
        return pulumi.get(self, "hide_web")

    @hide_web.setter
    def hide_web(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_web", value)

    @_builtins.property
    @pulumi.getter
    def logo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        """
        return pulumi.get(self, "logo")

    @logo.setter
    def logo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "logo", value)

    @_builtins.property
    @pulumi.getter(name="preconfiguredApp")
    def preconfigured_app(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Tells Okta to use an existing application in their application catalog, as opposed to a custom application.
        """
        return pulumi.get(self, "preconfigured_app")

    @preconfigured_app.setter
    def preconfigured_app(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "preconfigured_app", value)

    @_builtins.property
    @pulumi.getter(name="revealPassword")
    def reveal_password(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow user to reveal password. Default is false. It can not be set to true if credentials*scheme is "ADMIN*SETS*CREDENTIALS", "SHARED*USERNAME*AND*PASSWORD" or "EXTERNAL*PASSWORD*SYNC".
        """
        return pulumi.get(self, "reveal_password")

    @reveal_password.setter
    def reveal_password(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "reveal_password", value)

    @_builtins.property
    @pulumi.getter(name="sharedPassword")
    def shared_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Shared password, required for certain schemes.
        """
        return pulumi.get(self, "shared_password")

    @shared_password.setter
    def shared_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_password", value)

    @_builtins.property
    @pulumi.getter(name="sharedUsername")
    def shared_username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Shared username, required for certain schemes.
        """
        return pulumi.get(self, "shared_username")

    @shared_username.setter
    def shared_username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_username", value)

    @_builtins.property
    @pulumi.getter(name="signOnRedirectUrl")
    def sign_on_redirect_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Post login redirect URL
        """
        return pulumi.get(self, "sign_on_redirect_url")

    @sign_on_redirect_url.setter
    def sign_on_redirect_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_on_redirect_url", value)

    @_builtins.property
    @pulumi.getter(name="signOnUrl")
    def sign_on_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Login URL
        """
        return pulumi.get(self, "sign_on_url")

    @sign_on_url.setter
    def sign_on_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_on_url", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of application. By default, it is `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="userNameTemplate")
    def user_name_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username template. Default: `${source.login}`
        """
        return pulumi.get(self, "user_name_template")

    @user_name_template.setter
    def user_name_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name_template", value)

    @_builtins.property
    @pulumi.getter(name="userNameTemplatePushStatus")
    def user_name_template_push_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Push username on update. Valid values: `PUSH` and `DONT_PUSH`
        """
        return pulumi.get(self, "user_name_template_push_status")

    @user_name_template_push_status.setter
    def user_name_template_push_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name_template_push_status", value)

    @_builtins.property
    @pulumi.getter(name="userNameTemplateSuffix")
    def user_name_template_suffix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username template suffix
        """
        return pulumi.get(self, "user_name_template_suffix")

    @user_name_template_suffix.setter
    def user_name_template_suffix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name_template_suffix", value)

    @_builtins.property
    @pulumi.getter(name="userNameTemplateType")
    def user_name_template_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username template type. Default: `BUILT_IN`
        """
        return pulumi.get(self, "user_name_template_type")

    @user_name_template_type.setter
    def user_name_template_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name_template_type", value)


@pulumi.input_type
class _AutoLoginState:
    def __init__(__self__, *,
                 accessibility_error_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 accessibility_login_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 accessibility_self_service: Optional[pulumi.Input[_builtins.bool]] = None,
                 admin_note: Optional[pulumi.Input[_builtins.str]] = None,
                 app_links_json: Optional[pulumi.Input[_builtins.str]] = None,
                 app_settings_json: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_submit_toolbar: Optional[pulumi.Input[_builtins.bool]] = None,
                 credentials_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 enduser_note: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_ios: Optional[pulumi.Input[_builtins.bool]] = None,
                 hide_web: Optional[pulumi.Input[_builtins.bool]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 logo: Optional[pulumi.Input[_builtins.str]] = None,
                 logo_url: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 preconfigured_app: Optional[pulumi.Input[_builtins.str]] = None,
                 reveal_password: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_password: Optional[pulumi.Input[_builtins.str]] = None,
                 shared_username: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_on_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_on_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_on_url: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_push_status: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AutoLogin resources.
        :param pulumi.Input[_builtins.str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[_builtins.str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[_builtins.bool] accessibility_self_service: Enable self service. Default is `false`
        :param pulumi.Input[_builtins.str] admin_note: Application notes for admins.
        :param pulumi.Input[_builtins.str] app_links_json: Displays specific appLinks for the app. The value for each application link should be boolean.
        :param pulumi.Input[_builtins.str] app_settings_json: Application settings in JSON format
        :param pulumi.Input[_builtins.bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[_builtins.str] credentials_scheme: Application credentials scheme. One of: `EDIT_USERNAME_AND_PASSWORD`, `ADMIN_SETS_CREDENTIALS`, `EDIT_PASSWORD_ONLY`, `EXTERNAL_PASSWORD_SYNC`, or `SHARED_USERNAME_AND_PASSWORD`
        :param pulumi.Input[_builtins.str] enduser_note: Application notes for end users.
        :param pulumi.Input[_builtins.bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[_builtins.bool] hide_web: Do not display application icon to users
        :param pulumi.Input[_builtins.str] label: The Application's display name.
        :param pulumi.Input[_builtins.str] logo: Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        :param pulumi.Input[_builtins.str] logo_url: URL of the application's logo
        :param pulumi.Input[_builtins.str] name: Name of the app.
        :param pulumi.Input[_builtins.str] preconfigured_app: Tells Okta to use an existing application in their application catalog, as opposed to a custom application.
        :param pulumi.Input[_builtins.bool] reveal_password: Allow user to reveal password. Default is false. It can not be set to true if credentials*scheme is "ADMIN*SETS*CREDENTIALS", "SHARED*USERNAME*AND*PASSWORD" or "EXTERNAL*PASSWORD*SYNC".
        :param pulumi.Input[_builtins.str] shared_password: Shared password, required for certain schemes.
        :param pulumi.Input[_builtins.str] shared_username: Shared username, required for certain schemes.
        :param pulumi.Input[_builtins.str] sign_on_mode: Sign on mode of application.
        :param pulumi.Input[_builtins.str] sign_on_redirect_url: Post login redirect URL
        :param pulumi.Input[_builtins.str] sign_on_url: Login URL
        :param pulumi.Input[_builtins.str] status: Status of application. By default, it is `ACTIVE`
        :param pulumi.Input[_builtins.str] user_name_template: Username template. Default: `${source.login}`
        :param pulumi.Input[_builtins.str] user_name_template_push_status: Push username on update. Valid values: `PUSH` and `DONT_PUSH`
        :param pulumi.Input[_builtins.str] user_name_template_suffix: Username template suffix
        :param pulumi.Input[_builtins.str] user_name_template_type: Username template type. Default: `BUILT_IN`
        """
        if accessibility_error_redirect_url is not None:
            pulumi.set(__self__, "accessibility_error_redirect_url", accessibility_error_redirect_url)
        if accessibility_login_redirect_url is not None:
            pulumi.set(__self__, "accessibility_login_redirect_url", accessibility_login_redirect_url)
        if accessibility_self_service is not None:
            pulumi.set(__self__, "accessibility_self_service", accessibility_self_service)
        if admin_note is not None:
            pulumi.set(__self__, "admin_note", admin_note)
        if app_links_json is not None:
            pulumi.set(__self__, "app_links_json", app_links_json)
        if app_settings_json is not None:
            pulumi.set(__self__, "app_settings_json", app_settings_json)
        if auto_submit_toolbar is not None:
            pulumi.set(__self__, "auto_submit_toolbar", auto_submit_toolbar)
        if credentials_scheme is not None:
            pulumi.set(__self__, "credentials_scheme", credentials_scheme)
        if enduser_note is not None:
            pulumi.set(__self__, "enduser_note", enduser_note)
        if hide_ios is not None:
            pulumi.set(__self__, "hide_ios", hide_ios)
        if hide_web is not None:
            pulumi.set(__self__, "hide_web", hide_web)
        if label is not None:
            pulumi.set(__self__, "label", label)
        if logo is not None:
            pulumi.set(__self__, "logo", logo)
        if logo_url is not None:
            pulumi.set(__self__, "logo_url", logo_url)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if preconfigured_app is not None:
            pulumi.set(__self__, "preconfigured_app", preconfigured_app)
        if reveal_password is not None:
            pulumi.set(__self__, "reveal_password", reveal_password)
        if shared_password is not None:
            pulumi.set(__self__, "shared_password", shared_password)
        if shared_username is not None:
            pulumi.set(__self__, "shared_username", shared_username)
        if sign_on_mode is not None:
            pulumi.set(__self__, "sign_on_mode", sign_on_mode)
        if sign_on_redirect_url is not None:
            pulumi.set(__self__, "sign_on_redirect_url", sign_on_redirect_url)
        if sign_on_url is not None:
            pulumi.set(__self__, "sign_on_url", sign_on_url)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if user_name_template is not None:
            pulumi.set(__self__, "user_name_template", user_name_template)
        if user_name_template_push_status is not None:
            pulumi.set(__self__, "user_name_template_push_status", user_name_template_push_status)
        if user_name_template_suffix is not None:
            pulumi.set(__self__, "user_name_template_suffix", user_name_template_suffix)
        if user_name_template_type is not None:
            pulumi.set(__self__, "user_name_template_type", user_name_template_type)

    @_builtins.property
    @pulumi.getter(name="accessibilityErrorRedirectUrl")
    def accessibility_error_redirect_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom error page URL
        """
        return pulumi.get(self, "accessibility_error_redirect_url")

    @accessibility_error_redirect_url.setter
    def accessibility_error_redirect_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "accessibility_error_redirect_url", value)

    @_builtins.property
    @pulumi.getter(name="accessibilityLoginRedirectUrl")
    def accessibility_login_redirect_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom login page URL
        """
        return pulumi.get(self, "accessibility_login_redirect_url")

    @accessibility_login_redirect_url.setter
    def accessibility_login_redirect_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "accessibility_login_redirect_url", value)

    @_builtins.property
    @pulumi.getter(name="accessibilitySelfService")
    def accessibility_self_service(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable self service. Default is `false`
        """
        return pulumi.get(self, "accessibility_self_service")

    @accessibility_self_service.setter
    def accessibility_self_service(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "accessibility_self_service", value)

    @_builtins.property
    @pulumi.getter(name="adminNote")
    def admin_note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application notes for admins.
        """
        return pulumi.get(self, "admin_note")

    @admin_note.setter
    def admin_note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "admin_note", value)

    @_builtins.property
    @pulumi.getter(name="appLinksJson")
    def app_links_json(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Displays specific appLinks for the app. The value for each application link should be boolean.
        """
        return pulumi.get(self, "app_links_json")

    @app_links_json.setter
    def app_links_json(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_links_json", value)

    @_builtins.property
    @pulumi.getter(name="appSettingsJson")
    def app_settings_json(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application settings in JSON format
        """
        return pulumi.get(self, "app_settings_json")

    @app_settings_json.setter
    def app_settings_json(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_settings_json", value)

    @_builtins.property
    @pulumi.getter(name="autoSubmitToolbar")
    def auto_submit_toolbar(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Display auto submit toolbar
        """
        return pulumi.get(self, "auto_submit_toolbar")

    @auto_submit_toolbar.setter
    def auto_submit_toolbar(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_submit_toolbar", value)

    @_builtins.property
    @pulumi.getter(name="credentialsScheme")
    def credentials_scheme(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application credentials scheme. One of: `EDIT_USERNAME_AND_PASSWORD`, `ADMIN_SETS_CREDENTIALS`, `EDIT_PASSWORD_ONLY`, `EXTERNAL_PASSWORD_SYNC`, or `SHARED_USERNAME_AND_PASSWORD`
        """
        return pulumi.get(self, "credentials_scheme")

    @credentials_scheme.setter
    def credentials_scheme(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "credentials_scheme", value)

    @_builtins.property
    @pulumi.getter(name="enduserNote")
    def enduser_note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application notes for end users.
        """
        return pulumi.get(self, "enduser_note")

    @enduser_note.setter
    def enduser_note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "enduser_note", value)

    @_builtins.property
    @pulumi.getter(name="hideIos")
    def hide_ios(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Do not display application icon on mobile app
        """
        return pulumi.get(self, "hide_ios")

    @hide_ios.setter
    def hide_ios(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_ios", value)

    @_builtins.property
    @pulumi.getter(name="hideWeb")
    def hide_web(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Do not display application icon to users
        """
        return pulumi.get(self, "hide_web")

    @hide_web.setter
    def hide_web(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_web", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Application's display name.
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter
    def logo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        """
        return pulumi.get(self, "logo")

    @logo.setter
    def logo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "logo", value)

    @_builtins.property
    @pulumi.getter(name="logoUrl")
    def logo_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the application's logo
        """
        return pulumi.get(self, "logo_url")

    @logo_url.setter
    def logo_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "logo_url", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the app.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="preconfiguredApp")
    def preconfigured_app(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Tells Okta to use an existing application in their application catalog, as opposed to a custom application.
        """
        return pulumi.get(self, "preconfigured_app")

    @preconfigured_app.setter
    def preconfigured_app(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "preconfigured_app", value)

    @_builtins.property
    @pulumi.getter(name="revealPassword")
    def reveal_password(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow user to reveal password. Default is false. It can not be set to true if credentials*scheme is "ADMIN*SETS*CREDENTIALS", "SHARED*USERNAME*AND*PASSWORD" or "EXTERNAL*PASSWORD*SYNC".
        """
        return pulumi.get(self, "reveal_password")

    @reveal_password.setter
    def reveal_password(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "reveal_password", value)

    @_builtins.property
    @pulumi.getter(name="sharedPassword")
    def shared_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Shared password, required for certain schemes.
        """
        return pulumi.get(self, "shared_password")

    @shared_password.setter
    def shared_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_password", value)

    @_builtins.property
    @pulumi.getter(name="sharedUsername")
    def shared_username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Shared username, required for certain schemes.
        """
        return pulumi.get(self, "shared_username")

    @shared_username.setter
    def shared_username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "shared_username", value)

    @_builtins.property
    @pulumi.getter(name="signOnMode")
    def sign_on_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Sign on mode of application.
        """
        return pulumi.get(self, "sign_on_mode")

    @sign_on_mode.setter
    def sign_on_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_on_mode", value)

    @_builtins.property
    @pulumi.getter(name="signOnRedirectUrl")
    def sign_on_redirect_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Post login redirect URL
        """
        return pulumi.get(self, "sign_on_redirect_url")

    @sign_on_redirect_url.setter
    def sign_on_redirect_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_on_redirect_url", value)

    @_builtins.property
    @pulumi.getter(name="signOnUrl")
    def sign_on_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Login URL
        """
        return pulumi.get(self, "sign_on_url")

    @sign_on_url.setter
    def sign_on_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_on_url", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of application. By default, it is `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="userNameTemplate")
    def user_name_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username template. Default: `${source.login}`
        """
        return pulumi.get(self, "user_name_template")

    @user_name_template.setter
    def user_name_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name_template", value)

    @_builtins.property
    @pulumi.getter(name="userNameTemplatePushStatus")
    def user_name_template_push_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Push username on update. Valid values: `PUSH` and `DONT_PUSH`
        """
        return pulumi.get(self, "user_name_template_push_status")

    @user_name_template_push_status.setter
    def user_name_template_push_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name_template_push_status", value)

    @_builtins.property
    @pulumi.getter(name="userNameTemplateSuffix")
    def user_name_template_suffix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username template suffix
        """
        return pulumi.get(self, "user_name_template_suffix")

    @user_name_template_suffix.setter
    def user_name_template_suffix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name_template_suffix", value)

    @_builtins.property
    @pulumi.getter(name="userNameTemplateType")
    def user_name_template_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username template type. Default: `BUILT_IN`
        """
        return pulumi.get(self, "user_name_template_type")

    @user_name_template_type.setter
    def user_name_template_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name_template_type", value)


@pulumi.type_token("okta:app/autoLogin:AutoLogin")
class AutoLogin(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accessibility_error_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 accessibility_login_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 accessibility_self_service: Optional[pulumi.Input[_builtins.bool]] = None,
                 admin_note: Optional[pulumi.Input[_builtins.str]] = None,
                 app_links_json: Optional[pulumi.Input[_builtins.str]] = None,
                 app_settings_json: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_submit_toolbar: Optional[pulumi.Input[_builtins.bool]] = None,
                 credentials_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 enduser_note: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_ios: Optional[pulumi.Input[_builtins.bool]] = None,
                 hide_web: Optional[pulumi.Input[_builtins.bool]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 logo: Optional[pulumi.Input[_builtins.str]] = None,
                 preconfigured_app: Optional[pulumi.Input[_builtins.str]] = None,
                 reveal_password: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_password: Optional[pulumi.Input[_builtins.str]] = None,
                 shared_username: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_on_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_on_url: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_push_status: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource allows you to create and configure an Auto Login Okta Application.

        > During an apply if there is change in status the app will first be
        activated or deactivated in accordance with the status change. Then, all
        other arguments that changed will be applied.

        ## Import

        ```sh
        $ pulumi import okta:app/autoLogin:AutoLogin example <app_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[_builtins.str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[_builtins.bool] accessibility_self_service: Enable self service. Default is `false`
        :param pulumi.Input[_builtins.str] admin_note: Application notes for admins.
        :param pulumi.Input[_builtins.str] app_links_json: Displays specific appLinks for the app. The value for each application link should be boolean.
        :param pulumi.Input[_builtins.str] app_settings_json: Application settings in JSON format
        :param pulumi.Input[_builtins.bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[_builtins.str] credentials_scheme: Application credentials scheme. One of: `EDIT_USERNAME_AND_PASSWORD`, `ADMIN_SETS_CREDENTIALS`, `EDIT_PASSWORD_ONLY`, `EXTERNAL_PASSWORD_SYNC`, or `SHARED_USERNAME_AND_PASSWORD`
        :param pulumi.Input[_builtins.str] enduser_note: Application notes for end users.
        :param pulumi.Input[_builtins.bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[_builtins.bool] hide_web: Do not display application icon to users
        :param pulumi.Input[_builtins.str] label: The Application's display name.
        :param pulumi.Input[_builtins.str] logo: Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        :param pulumi.Input[_builtins.str] preconfigured_app: Tells Okta to use an existing application in their application catalog, as opposed to a custom application.
        :param pulumi.Input[_builtins.bool] reveal_password: Allow user to reveal password. Default is false. It can not be set to true if credentials*scheme is "ADMIN*SETS*CREDENTIALS", "SHARED*USERNAME*AND*PASSWORD" or "EXTERNAL*PASSWORD*SYNC".
        :param pulumi.Input[_builtins.str] shared_password: Shared password, required for certain schemes.
        :param pulumi.Input[_builtins.str] shared_username: Shared username, required for certain schemes.
        :param pulumi.Input[_builtins.str] sign_on_redirect_url: Post login redirect URL
        :param pulumi.Input[_builtins.str] sign_on_url: Login URL
        :param pulumi.Input[_builtins.str] status: Status of application. By default, it is `ACTIVE`
        :param pulumi.Input[_builtins.str] user_name_template: Username template. Default: `${source.login}`
        :param pulumi.Input[_builtins.str] user_name_template_push_status: Push username on update. Valid values: `PUSH` and `DONT_PUSH`
        :param pulumi.Input[_builtins.str] user_name_template_suffix: Username template suffix
        :param pulumi.Input[_builtins.str] user_name_template_type: Username template type. Default: `BUILT_IN`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AutoLoginArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and configure an Auto Login Okta Application.

        > During an apply if there is change in status the app will first be
        activated or deactivated in accordance with the status change. Then, all
        other arguments that changed will be applied.

        ## Import

        ```sh
        $ pulumi import okta:app/autoLogin:AutoLogin example <app_id>
        ```

        :param str resource_name: The name of the resource.
        :param AutoLoginArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AutoLoginArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accessibility_error_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 accessibility_login_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 accessibility_self_service: Optional[pulumi.Input[_builtins.bool]] = None,
                 admin_note: Optional[pulumi.Input[_builtins.str]] = None,
                 app_links_json: Optional[pulumi.Input[_builtins.str]] = None,
                 app_settings_json: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_submit_toolbar: Optional[pulumi.Input[_builtins.bool]] = None,
                 credentials_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 enduser_note: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_ios: Optional[pulumi.Input[_builtins.bool]] = None,
                 hide_web: Optional[pulumi.Input[_builtins.bool]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 logo: Optional[pulumi.Input[_builtins.str]] = None,
                 preconfigured_app: Optional[pulumi.Input[_builtins.str]] = None,
                 reveal_password: Optional[pulumi.Input[_builtins.bool]] = None,
                 shared_password: Optional[pulumi.Input[_builtins.str]] = None,
                 shared_username: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_on_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_on_url: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_push_status: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name_template_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AutoLoginArgs.__new__(AutoLoginArgs)

            __props__.__dict__["accessibility_error_redirect_url"] = accessibility_error_redirect_url
            __props__.__dict__["accessibility_login_redirect_url"] = accessibility_login_redirect_url
            __props__.__dict__["accessibility_self_service"] = accessibility_self_service
            __props__.__dict__["admin_note"] = admin_note
            __props__.__dict__["app_links_json"] = app_links_json
            __props__.__dict__["app_settings_json"] = app_settings_json
            __props__.__dict__["auto_submit_toolbar"] = auto_submit_toolbar
            __props__.__dict__["credentials_scheme"] = credentials_scheme
            __props__.__dict__["enduser_note"] = enduser_note
            __props__.__dict__["hide_ios"] = hide_ios
            __props__.__dict__["hide_web"] = hide_web
            if label is None and not opts.urn:
                raise TypeError("Missing required property 'label'")
            __props__.__dict__["label"] = label
            __props__.__dict__["logo"] = logo
            __props__.__dict__["preconfigured_app"] = preconfigured_app
            __props__.__dict__["reveal_password"] = reveal_password
            __props__.__dict__["shared_password"] = shared_password
            __props__.__dict__["shared_username"] = shared_username
            __props__.__dict__["sign_on_redirect_url"] = sign_on_redirect_url
            __props__.__dict__["sign_on_url"] = sign_on_url
            __props__.__dict__["status"] = status
            __props__.__dict__["user_name_template"] = user_name_template
            __props__.__dict__["user_name_template_push_status"] = user_name_template_push_status
            __props__.__dict__["user_name_template_suffix"] = user_name_template_suffix
            __props__.__dict__["user_name_template_type"] = user_name_template_type
            __props__.__dict__["logo_url"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["sign_on_mode"] = None
        super(AutoLogin, __self__).__init__(
            'okta:app/autoLogin:AutoLogin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accessibility_error_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
            accessibility_login_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
            accessibility_self_service: Optional[pulumi.Input[_builtins.bool]] = None,
            admin_note: Optional[pulumi.Input[_builtins.str]] = None,
            app_links_json: Optional[pulumi.Input[_builtins.str]] = None,
            app_settings_json: Optional[pulumi.Input[_builtins.str]] = None,
            auto_submit_toolbar: Optional[pulumi.Input[_builtins.bool]] = None,
            credentials_scheme: Optional[pulumi.Input[_builtins.str]] = None,
            enduser_note: Optional[pulumi.Input[_builtins.str]] = None,
            hide_ios: Optional[pulumi.Input[_builtins.bool]] = None,
            hide_web: Optional[pulumi.Input[_builtins.bool]] = None,
            label: Optional[pulumi.Input[_builtins.str]] = None,
            logo: Optional[pulumi.Input[_builtins.str]] = None,
            logo_url: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            preconfigured_app: Optional[pulumi.Input[_builtins.str]] = None,
            reveal_password: Optional[pulumi.Input[_builtins.bool]] = None,
            shared_password: Optional[pulumi.Input[_builtins.str]] = None,
            shared_username: Optional[pulumi.Input[_builtins.str]] = None,
            sign_on_mode: Optional[pulumi.Input[_builtins.str]] = None,
            sign_on_redirect_url: Optional[pulumi.Input[_builtins.str]] = None,
            sign_on_url: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            user_name_template: Optional[pulumi.Input[_builtins.str]] = None,
            user_name_template_push_status: Optional[pulumi.Input[_builtins.str]] = None,
            user_name_template_suffix: Optional[pulumi.Input[_builtins.str]] = None,
            user_name_template_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'AutoLogin':
        """
        Get an existing AutoLogin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[_builtins.str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[_builtins.bool] accessibility_self_service: Enable self service. Default is `false`
        :param pulumi.Input[_builtins.str] admin_note: Application notes for admins.
        :param pulumi.Input[_builtins.str] app_links_json: Displays specific appLinks for the app. The value for each application link should be boolean.
        :param pulumi.Input[_builtins.str] app_settings_json: Application settings in JSON format
        :param pulumi.Input[_builtins.bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[_builtins.str] credentials_scheme: Application credentials scheme. One of: `EDIT_USERNAME_AND_PASSWORD`, `ADMIN_SETS_CREDENTIALS`, `EDIT_PASSWORD_ONLY`, `EXTERNAL_PASSWORD_SYNC`, or `SHARED_USERNAME_AND_PASSWORD`
        :param pulumi.Input[_builtins.str] enduser_note: Application notes for end users.
        :param pulumi.Input[_builtins.bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[_builtins.bool] hide_web: Do not display application icon to users
        :param pulumi.Input[_builtins.str] label: The Application's display name.
        :param pulumi.Input[_builtins.str] logo: Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        :param pulumi.Input[_builtins.str] logo_url: URL of the application's logo
        :param pulumi.Input[_builtins.str] name: Name of the app.
        :param pulumi.Input[_builtins.str] preconfigured_app: Tells Okta to use an existing application in their application catalog, as opposed to a custom application.
        :param pulumi.Input[_builtins.bool] reveal_password: Allow user to reveal password. Default is false. It can not be set to true if credentials*scheme is "ADMIN*SETS*CREDENTIALS", "SHARED*USERNAME*AND*PASSWORD" or "EXTERNAL*PASSWORD*SYNC".
        :param pulumi.Input[_builtins.str] shared_password: Shared password, required for certain schemes.
        :param pulumi.Input[_builtins.str] shared_username: Shared username, required for certain schemes.
        :param pulumi.Input[_builtins.str] sign_on_mode: Sign on mode of application.
        :param pulumi.Input[_builtins.str] sign_on_redirect_url: Post login redirect URL
        :param pulumi.Input[_builtins.str] sign_on_url: Login URL
        :param pulumi.Input[_builtins.str] status: Status of application. By default, it is `ACTIVE`
        :param pulumi.Input[_builtins.str] user_name_template: Username template. Default: `${source.login}`
        :param pulumi.Input[_builtins.str] user_name_template_push_status: Push username on update. Valid values: `PUSH` and `DONT_PUSH`
        :param pulumi.Input[_builtins.str] user_name_template_suffix: Username template suffix
        :param pulumi.Input[_builtins.str] user_name_template_type: Username template type. Default: `BUILT_IN`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AutoLoginState.__new__(_AutoLoginState)

        __props__.__dict__["accessibility_error_redirect_url"] = accessibility_error_redirect_url
        __props__.__dict__["accessibility_login_redirect_url"] = accessibility_login_redirect_url
        __props__.__dict__["accessibility_self_service"] = accessibility_self_service
        __props__.__dict__["admin_note"] = admin_note
        __props__.__dict__["app_links_json"] = app_links_json
        __props__.__dict__["app_settings_json"] = app_settings_json
        __props__.__dict__["auto_submit_toolbar"] = auto_submit_toolbar
        __props__.__dict__["credentials_scheme"] = credentials_scheme
        __props__.__dict__["enduser_note"] = enduser_note
        __props__.__dict__["hide_ios"] = hide_ios
        __props__.__dict__["hide_web"] = hide_web
        __props__.__dict__["label"] = label
        __props__.__dict__["logo"] = logo
        __props__.__dict__["logo_url"] = logo_url
        __props__.__dict__["name"] = name
        __props__.__dict__["preconfigured_app"] = preconfigured_app
        __props__.__dict__["reveal_password"] = reveal_password
        __props__.__dict__["shared_password"] = shared_password
        __props__.__dict__["shared_username"] = shared_username
        __props__.__dict__["sign_on_mode"] = sign_on_mode
        __props__.__dict__["sign_on_redirect_url"] = sign_on_redirect_url
        __props__.__dict__["sign_on_url"] = sign_on_url
        __props__.__dict__["status"] = status
        __props__.__dict__["user_name_template"] = user_name_template
        __props__.__dict__["user_name_template_push_status"] = user_name_template_push_status
        __props__.__dict__["user_name_template_suffix"] = user_name_template_suffix
        __props__.__dict__["user_name_template_type"] = user_name_template_type
        return AutoLogin(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessibilityErrorRedirectUrl")
    def accessibility_error_redirect_url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Custom error page URL
        """
        return pulumi.get(self, "accessibility_error_redirect_url")

    @_builtins.property
    @pulumi.getter(name="accessibilityLoginRedirectUrl")
    def accessibility_login_redirect_url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Custom login page URL
        """
        return pulumi.get(self, "accessibility_login_redirect_url")

    @_builtins.property
    @pulumi.getter(name="accessibilitySelfService")
    def accessibility_self_service(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable self service. Default is `false`
        """
        return pulumi.get(self, "accessibility_self_service")

    @_builtins.property
    @pulumi.getter(name="adminNote")
    def admin_note(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Application notes for admins.
        """
        return pulumi.get(self, "admin_note")

    @_builtins.property
    @pulumi.getter(name="appLinksJson")
    def app_links_json(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Displays specific appLinks for the app. The value for each application link should be boolean.
        """
        return pulumi.get(self, "app_links_json")

    @_builtins.property
    @pulumi.getter(name="appSettingsJson")
    def app_settings_json(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Application settings in JSON format
        """
        return pulumi.get(self, "app_settings_json")

    @_builtins.property
    @pulumi.getter(name="autoSubmitToolbar")
    def auto_submit_toolbar(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Display auto submit toolbar
        """
        return pulumi.get(self, "auto_submit_toolbar")

    @_builtins.property
    @pulumi.getter(name="credentialsScheme")
    def credentials_scheme(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Application credentials scheme. One of: `EDIT_USERNAME_AND_PASSWORD`, `ADMIN_SETS_CREDENTIALS`, `EDIT_PASSWORD_ONLY`, `EXTERNAL_PASSWORD_SYNC`, or `SHARED_USERNAME_AND_PASSWORD`
        """
        return pulumi.get(self, "credentials_scheme")

    @_builtins.property
    @pulumi.getter(name="enduserNote")
    def enduser_note(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Application notes for end users.
        """
        return pulumi.get(self, "enduser_note")

    @_builtins.property
    @pulumi.getter(name="hideIos")
    def hide_ios(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Do not display application icon on mobile app
        """
        return pulumi.get(self, "hide_ios")

    @_builtins.property
    @pulumi.getter(name="hideWeb")
    def hide_web(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Do not display application icon to users
        """
        return pulumi.get(self, "hide_web")

    @_builtins.property
    @pulumi.getter
    def label(self) -> pulumi.Output[_builtins.str]:
        """
        The Application's display name.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def logo(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Local file path to the logo. The file must be in PNG, JPG, or GIF format, and less than 1 MB in size.
        """
        return pulumi.get(self, "logo")

    @_builtins.property
    @pulumi.getter(name="logoUrl")
    def logo_url(self) -> pulumi.Output[_builtins.str]:
        """
        URL of the application's logo
        """
        return pulumi.get(self, "logo_url")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the app.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="preconfiguredApp")
    def preconfigured_app(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Tells Okta to use an existing application in their application catalog, as opposed to a custom application.
        """
        return pulumi.get(self, "preconfigured_app")

    @_builtins.property
    @pulumi.getter(name="revealPassword")
    def reveal_password(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Allow user to reveal password. Default is false. It can not be set to true if credentials*scheme is "ADMIN*SETS*CREDENTIALS", "SHARED*USERNAME*AND*PASSWORD" or "EXTERNAL*PASSWORD*SYNC".
        """
        return pulumi.get(self, "reveal_password")

    @_builtins.property
    @pulumi.getter(name="sharedPassword")
    def shared_password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Shared password, required for certain schemes.
        """
        return pulumi.get(self, "shared_password")

    @_builtins.property
    @pulumi.getter(name="sharedUsername")
    def shared_username(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Shared username, required for certain schemes.
        """
        return pulumi.get(self, "shared_username")

    @_builtins.property
    @pulumi.getter(name="signOnMode")
    def sign_on_mode(self) -> pulumi.Output[_builtins.str]:
        """
        Sign on mode of application.
        """
        return pulumi.get(self, "sign_on_mode")

    @_builtins.property
    @pulumi.getter(name="signOnRedirectUrl")
    def sign_on_redirect_url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Post login redirect URL
        """
        return pulumi.get(self, "sign_on_redirect_url")

    @_builtins.property
    @pulumi.getter(name="signOnUrl")
    def sign_on_url(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Login URL
        """
        return pulumi.get(self, "sign_on_url")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Status of application. By default, it is `ACTIVE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="userNameTemplate")
    def user_name_template(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Username template. Default: `${source.login}`
        """
        return pulumi.get(self, "user_name_template")

    @_builtins.property
    @pulumi.getter(name="userNameTemplatePushStatus")
    def user_name_template_push_status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Push username on update. Valid values: `PUSH` and `DONT_PUSH`
        """
        return pulumi.get(self, "user_name_template_push_status")

    @_builtins.property
    @pulumi.getter(name="userNameTemplateSuffix")
    def user_name_template_suffix(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Username template suffix
        """
        return pulumi.get(self, "user_name_template_suffix")

    @_builtins.property
    @pulumi.getter(name="userNameTemplateType")
    def user_name_template_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Username template type. Default: `BUILT_IN`
        """
        return pulumi.get(self, "user_name_template_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAppUserAssignmentsResult',
    'AwaitableGetAppUserAssignmentsResult',
    'get_app_user_assignments',
    'get_app_user_assignments_output',
]

@pulumi.output_type
class GetAppUserAssignmentsResult:
    """
    A collection of values returned by getAppUserAssignments.
    """
    def __init__(__self__, id=None, users=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the Okta App being queried for groups
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def users(self) -> Sequence[_builtins.str]:
        """
        List of user IDs assigned to the app
        """
        return pulumi.get(self, "users")


class AwaitableGetAppUserAssignmentsResult(GetAppUserAssignmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppUserAssignmentsResult(
            id=self.id,
            users=self.users)


def get_app_user_assignments(id: Optional[_builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppUserAssignmentsResult:
    """
    Get a set of users assigned to an Okta application.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_app_user_assignments(id=test_okta_app_oauth["id"])
    ```


    :param _builtins.str id: ID of the Okta App being queried for groups
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getAppUserAssignments:getAppUserAssignments', __args__, opts=opts, typ=GetAppUserAssignmentsResult).value

    return AwaitableGetAppUserAssignmentsResult(
        id=pulumi.get(__ret__, 'id'),
        users=pulumi.get(__ret__, 'users'))
def get_app_user_assignments_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAppUserAssignmentsResult]:
    """
    Get a set of users assigned to an Okta application.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_app_user_assignments(id=test_okta_app_oauth["id"])
    ```


    :param _builtins.str id: ID of the Okta App being queried for groups
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getAppUserAssignments:getAppUserAssignments', __args__, opts=opts, typ=GetAppUserAssignmentsResult)
    return __ret__.apply(lambda __response__: GetAppUserAssignmentsResult(
        id=pulumi.get(__response__, 'id'),
        users=pulumi.get(__response__, 'users')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetRateLimitAdminNotificationSettingsResult',
    'AwaitableGetRateLimitAdminNotificationSettingsResult',
    'get_rate_limit_admin_notification_settings',
    'get_rate_limit_admin_notification_settings_output',
]

@pulumi.output_type
class GetRateLimitAdminNotificationSettingsResult:
    """
    A collection of values returned by getRateLimitAdminNotificationSettings.
    """
    def __init__(__self__, id=None, notifications_enabled=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if notifications_enabled and not isinstance(notifications_enabled, bool):
            raise TypeError("Expected argument 'notifications_enabled' to be a bool")
        pulumi.set(__self__, "notifications_enabled", notifications_enabled)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the principal. This is the ID of the API token or OAuth 2.0 app.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="notificationsEnabled")
    def notifications_enabled(self) -> _builtins.bool:
        """
        Enables or disables admin notifications for rate limiting events.
        """
        return pulumi.get(self, "notifications_enabled")


class AwaitableGetRateLimitAdminNotificationSettingsResult(GetRateLimitAdminNotificationSettingsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRateLimitAdminNotificationSettingsResult(
            id=self.id,
            notifications_enabled=self.notifications_enabled)


def get_rate_limit_admin_notification_settings(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRateLimitAdminNotificationSettingsResult:
    """
    Retrieves the currently configured Rate Limit Admin Notification Settings

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_rate_limit_admin_notification_settings()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getRateLimitAdminNotificationSettings:getRateLimitAdminNotificationSettings', __args__, opts=opts, typ=GetRateLimitAdminNotificationSettingsResult).value

    return AwaitableGetRateLimitAdminNotificationSettingsResult(
        id=pulumi.get(__ret__, 'id'),
        notifications_enabled=pulumi.get(__ret__, 'notifications_enabled'))
def get_rate_limit_admin_notification_settings_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRateLimitAdminNotificationSettingsResult]:
    """
    Retrieves the currently configured Rate Limit Admin Notification Settings

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_rate_limit_admin_notification_settings()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getRateLimitAdminNotificationSettings:getRateLimitAdminNotificationSettings', __args__, opts=opts, typ=GetRateLimitAdminNotificationSettingsResult)
    return __ret__.apply(lambda __response__: GetRateLimitAdminNotificationSettingsResult(
        id=pulumi.get(__response__, 'id'),
        notifications_enabled=pulumi.get(__response__, 'notifications_enabled')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCatalogEntryUserAccessRequestFieldsResult',
    'AwaitableGetCatalogEntryUserAccessRequestFieldsResult',
    'get_catalog_entry_user_access_request_fields',
    'get_catalog_entry_user_access_request_fields_output',
]

@pulumi.output_type
class GetCatalogEntryUserAccessRequestFieldsResult:
    """
    A collection of values returned by getCatalogEntryUserAccessRequestFields.
    """
    def __init__(__self__, datas=None, entry_id=None, id=None, user_id=None):
        if datas and not isinstance(datas, list):
            raise TypeError("Expected argument 'datas' to be a list")
        pulumi.set(__self__, "datas", datas)
        if entry_id and not isinstance(entry_id, str):
            raise TypeError("Expected argument 'entry_id' to be a str")
        pulumi.set(__self__, "entry_id", entry_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter
    def datas(self) -> Optional[Sequence['outputs.GetCatalogEntryUserAccessRequestFieldsDataResult']]:
        return pulumi.get(self, "datas")

    @_builtins.property
    @pulumi.getter(name="entryId")
    def entry_id(self) -> _builtins.str:
        """
        TThe ID of the catalog entry.
        """
        return pulumi.get(self, "entry_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> _builtins.str:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")


class AwaitableGetCatalogEntryUserAccessRequestFieldsResult(GetCatalogEntryUserAccessRequestFieldsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCatalogEntryUserAccessRequestFieldsResult(
            datas=self.datas,
            entry_id=self.entry_id,
            id=self.id,
            user_id=self.user_id)


def get_catalog_entry_user_access_request_fields(datas: Optional[Sequence[Union['GetCatalogEntryUserAccessRequestFieldsDataArgs', 'GetCatalogEntryUserAccessRequestFieldsDataArgsDict']]] = None,
                                                 entry_id: Optional[_builtins.str] = None,
                                                 user_id: Optional[_builtins.str] = None,
                                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCatalogEntryUserAccessRequestFieldsResult:
    """
    Get the request fields for catalog entry.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_catalog_entry_user_access_request_fields()
    ```


    :param _builtins.str entry_id: TThe ID of the catalog entry.
    :param _builtins.str user_id: The ID of the user.
    """
    __args__ = dict()
    __args__['datas'] = datas
    __args__['entryId'] = entry_id
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getCatalogEntryUserAccessRequestFields:getCatalogEntryUserAccessRequestFields', __args__, opts=opts, typ=GetCatalogEntryUserAccessRequestFieldsResult).value

    return AwaitableGetCatalogEntryUserAccessRequestFieldsResult(
        datas=pulumi.get(__ret__, 'datas'),
        entry_id=pulumi.get(__ret__, 'entry_id'),
        id=pulumi.get(__ret__, 'id'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_catalog_entry_user_access_request_fields_output(datas: Optional[pulumi.Input[Optional[Sequence[Union['GetCatalogEntryUserAccessRequestFieldsDataArgs', 'GetCatalogEntryUserAccessRequestFieldsDataArgsDict']]]]] = None,
                                                        entry_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                        user_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCatalogEntryUserAccessRequestFieldsResult]:
    """
    Get the request fields for catalog entry.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_catalog_entry_user_access_request_fields()
    ```


    :param _builtins.str entry_id: TThe ID of the catalog entry.
    :param _builtins.str user_id: The ID of the user.
    """
    __args__ = dict()
    __args__['datas'] = datas
    __args__['entryId'] = entry_id
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getCatalogEntryUserAccessRequestFields:getCatalogEntryUserAccessRequestFields', __args__, opts=opts, typ=GetCatalogEntryUserAccessRequestFieldsResult)
    return __ret__.apply(lambda __response__: GetCatalogEntryUserAccessRequestFieldsResult(
        datas=pulumi.get(__response__, 'datas'),
        entry_id=pulumi.get(__response__, 'entry_id'),
        id=pulumi.get(__response__, 'id'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EmailSenderArgs', 'EmailSender']

@pulumi.input_type
class EmailSenderArgs:
    def __init__(__self__, *,
                 from_address: pulumi.Input[_builtins.str],
                 from_name: pulumi.Input[_builtins.str],
                 subdomain: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a EmailSender resource.
        :param pulumi.Input[_builtins.str] from_address: Email address to send from
        :param pulumi.Input[_builtins.str] from_name: Name of sender
        :param pulumi.Input[_builtins.str] subdomain: Mail domain to send from
        """
        pulumi.set(__self__, "from_address", from_address)
        pulumi.set(__self__, "from_name", from_name)
        pulumi.set(__self__, "subdomain", subdomain)

    @_builtins.property
    @pulumi.getter(name="fromAddress")
    def from_address(self) -> pulumi.Input[_builtins.str]:
        """
        Email address to send from
        """
        return pulumi.get(self, "from_address")

    @from_address.setter
    def from_address(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "from_address", value)

    @_builtins.property
    @pulumi.getter(name="fromName")
    def from_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of sender
        """
        return pulumi.get(self, "from_name")

    @from_name.setter
    def from_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "from_name", value)

    @_builtins.property
    @pulumi.getter
    def subdomain(self) -> pulumi.Input[_builtins.str]:
        """
        Mail domain to send from
        """
        return pulumi.get(self, "subdomain")

    @subdomain.setter
    def subdomain(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "subdomain", value)


@pulumi.input_type
class _EmailSenderState:
    def __init__(__self__, *,
                 dns_records: Optional[pulumi.Input[Sequence[pulumi.Input['EmailSenderDnsRecordArgs']]]] = None,
                 from_address: Optional[pulumi.Input[_builtins.str]] = None,
                 from_name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 subdomain: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EmailSender resources.
        :param pulumi.Input[Sequence[pulumi.Input['EmailSenderDnsRecordArgs']]] dns_records: TXT and CNAME records to be registered for the Domain
        :param pulumi.Input[_builtins.str] from_address: Email address to send from
        :param pulumi.Input[_builtins.str] from_name: Name of sender
        :param pulumi.Input[_builtins.str] status: Verification status
        :param pulumi.Input[_builtins.str] subdomain: Mail domain to send from
        """
        if dns_records is not None:
            pulumi.set(__self__, "dns_records", dns_records)
        if from_address is not None:
            pulumi.set(__self__, "from_address", from_address)
        if from_name is not None:
            pulumi.set(__self__, "from_name", from_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subdomain is not None:
            pulumi.set(__self__, "subdomain", subdomain)

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EmailSenderDnsRecordArgs']]]]:
        """
        TXT and CNAME records to be registered for the Domain
        """
        return pulumi.get(self, "dns_records")

    @dns_records.setter
    def dns_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EmailSenderDnsRecordArgs']]]]):
        pulumi.set(self, "dns_records", value)

    @_builtins.property
    @pulumi.getter(name="fromAddress")
    def from_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Email address to send from
        """
        return pulumi.get(self, "from_address")

    @from_address.setter
    def from_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "from_address", value)

    @_builtins.property
    @pulumi.getter(name="fromName")
    def from_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of sender
        """
        return pulumi.get(self, "from_name")

    @from_name.setter
    def from_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "from_name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Verification status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def subdomain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Mail domain to send from
        """
        return pulumi.get(self, "subdomain")

    @subdomain.setter
    def subdomain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subdomain", value)


@pulumi.type_token("okta:index/emailSender:EmailSender")
class EmailSender(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 from_address: Optional[pulumi.Input[_builtins.str]] = None,
                 from_name: Optional[pulumi.Input[_builtins.str]] = None,
                 subdomain: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates custom email sender. This resource allows you to create and configure a custom email sender.

        > **DEPRECATED** The api for this resource has been deprecated. Please use `EmailDomain` instead.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EmailSender("example",
            from_name="Paul Atreides",
            from_address="no-reply@caladan.planet",
            subdomain="mail")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/emailSender:EmailSender example <sender_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] from_address: Email address to send from
        :param pulumi.Input[_builtins.str] from_name: Name of sender
        :param pulumi.Input[_builtins.str] subdomain: Mail domain to send from
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EmailSenderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates custom email sender. This resource allows you to create and configure a custom email sender.

        > **DEPRECATED** The api for this resource has been deprecated. Please use `EmailDomain` instead.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.EmailSender("example",
            from_name="Paul Atreides",
            from_address="no-reply@caladan.planet",
            subdomain="mail")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/emailSender:EmailSender example <sender_id>
        ```

        :param str resource_name: The name of the resource.
        :param EmailSenderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EmailSenderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 from_address: Optional[pulumi.Input[_builtins.str]] = None,
                 from_name: Optional[pulumi.Input[_builtins.str]] = None,
                 subdomain: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EmailSenderArgs.__new__(EmailSenderArgs)

            if from_address is None and not opts.urn:
                raise TypeError("Missing required property 'from_address'")
            __props__.__dict__["from_address"] = from_address
            if from_name is None and not opts.urn:
                raise TypeError("Missing required property 'from_name'")
            __props__.__dict__["from_name"] = from_name
            if subdomain is None and not opts.urn:
                raise TypeError("Missing required property 'subdomain'")
            __props__.__dict__["subdomain"] = subdomain
            __props__.__dict__["dns_records"] = None
            __props__.__dict__["status"] = None
        super(EmailSender, __self__).__init__(
            'okta:index/emailSender:EmailSender',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dns_records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EmailSenderDnsRecordArgs', 'EmailSenderDnsRecordArgsDict']]]]] = None,
            from_address: Optional[pulumi.Input[_builtins.str]] = None,
            from_name: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            subdomain: Optional[pulumi.Input[_builtins.str]] = None) -> 'EmailSender':
        """
        Get an existing EmailSender resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EmailSenderDnsRecordArgs', 'EmailSenderDnsRecordArgsDict']]]] dns_records: TXT and CNAME records to be registered for the Domain
        :param pulumi.Input[_builtins.str] from_address: Email address to send from
        :param pulumi.Input[_builtins.str] from_name: Name of sender
        :param pulumi.Input[_builtins.str] status: Verification status
        :param pulumi.Input[_builtins.str] subdomain: Mail domain to send from
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EmailSenderState.__new__(_EmailSenderState)

        __props__.__dict__["dns_records"] = dns_records
        __props__.__dict__["from_address"] = from_address
        __props__.__dict__["from_name"] = from_name
        __props__.__dict__["status"] = status
        __props__.__dict__["subdomain"] = subdomain
        return EmailSender(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> pulumi.Output[Sequence['outputs.EmailSenderDnsRecord']]:
        """
        TXT and CNAME records to be registered for the Domain
        """
        return pulumi.get(self, "dns_records")

    @_builtins.property
    @pulumi.getter(name="fromAddress")
    def from_address(self) -> pulumi.Output[_builtins.str]:
        """
        Email address to send from
        """
        return pulumi.get(self, "from_address")

    @_builtins.property
    @pulumi.getter(name="fromName")
    def from_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of sender
        """
        return pulumi.get(self, "from_name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Verification status
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def subdomain(self) -> pulumi.Output[_builtins.str]:
        """
        Mail domain to send from
        """
        return pulumi.get(self, "subdomain")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetRequestSequenceResult',
    'AwaitableGetRequestSequenceResult',
    'get_request_sequence',
    'get_request_sequence_output',
]

@pulumi.output_type
class GetRequestSequenceResult:
    """
    A collection of values returned by getRequestSequence.
    """
    def __init__(__self__, compatible_resource_types=None, description=None, id=None, link=None, name=None, resource_id=None):
        if compatible_resource_types and not isinstance(compatible_resource_types, list):
            raise TypeError("Expected argument 'compatible_resource_types' to be a list")
        pulumi.set(__self__, "compatible_resource_types", compatible_resource_types)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if link and not isinstance(link, str):
            raise TypeError("Expected argument 'link' to be a str")
        pulumi.set(__self__, "link", link)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        pulumi.set(__self__, "resource_id", resource_id)

    @_builtins.property
    @pulumi.getter(name="compatibleResourceTypes")
    def compatible_resource_types(self) -> Sequence[_builtins.str]:
        """
        Enum: `APP`, `GROUP`.
        """
        return pulumi.get(self, "compatible_resource_types")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the request condition.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The id of the sequence.Must be of 24 characters length.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def link(self) -> _builtins.str:
        """
        Link to edit the request sequence.
        """
        return pulumi.get(self, "link")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The access duration settings for the request condition
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> _builtins.str:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "resource_id")


class AwaitableGetRequestSequenceResult(GetRequestSequenceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRequestSequenceResult(
            compatible_resource_types=self.compatible_resource_types,
            description=self.description,
            id=self.id,
            link=self.link,
            name=self.name,
            resource_id=self.resource_id)


def get_request_sequence(id: Optional[_builtins.str] = None,
                         resource_id: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRequestSequenceResult:
    """
    Retrieves a access request sequence referenced by the specified resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_request_sequence(id="<sequence_id>",
        resource_id="<resource_id>")
    ```


    :param _builtins.str id: The id of the sequence.Must be of 24 characters length.
    :param _builtins.str resource_id: The id of the resource in Okta ID format.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['resourceId'] = resource_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getRequestSequence:getRequestSequence', __args__, opts=opts, typ=GetRequestSequenceResult).value

    return AwaitableGetRequestSequenceResult(
        compatible_resource_types=pulumi.get(__ret__, 'compatible_resource_types'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        link=pulumi.get(__ret__, 'link'),
        name=pulumi.get(__ret__, 'name'),
        resource_id=pulumi.get(__ret__, 'resource_id'))
def get_request_sequence_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRequestSequenceResult]:
    """
    Retrieves a access request sequence referenced by the specified resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_request_sequence(id="<sequence_id>",
        resource_id="<resource_id>")
    ```


    :param _builtins.str id: The id of the sequence.Must be of 24 characters length.
    :param _builtins.str resource_id: The id of the resource in Okta ID format.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['resourceId'] = resource_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getRequestSequence:getRequestSequence', __args__, opts=opts, typ=GetRequestSequenceResult)
    return __ret__.apply(lambda __response__: GetRequestSequenceResult(
        compatible_resource_types=pulumi.get(__response__, 'compatible_resource_types'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        link=pulumi.get(__response__, 'link'),
        name=pulumi.get(__response__, 'name'),
        resource_id=pulumi.get(__response__, 'resource_id')))
